import math

class Vector2(object):
    
    __slots__ = ['x', 'y']
    
    def __init__(self, x, y=None):
        if y is None:
            self.x, self.y = x
        else:
            self.x = x
            self.y = y

    def __add__(self, vector):
        return Vector2(self.x+vector.x, self.y+vector.y)

    def __abs__(self):
        return Vector2(abs(self.x), abs(self.y))

    def __div__(self, scalar):
        return Vector2(self.x/float(scalar), self.y/float(scalar))

    def __eq__(self, vector):
        return bool(self.x == vector.x and self.y == vector.y)

    def __ge__(self, vector):
        return len(self) >= len(vector)

    def __gt__(self, vector):
        return len(self) > len(vector)

    def __le__(self, vector):
        return len(self) <= len(vector)

    def __lt__(self, vector):
        return len(self) < len(vector)

    def __mul__(self, value):
        if isinstance(value, Vector2):
            return Vector2(self.x*vector.x, self.y*vector.y)
        else:
            return Vector2(self.x*value, self.y*value)

    def __ne__(self, vector):
        return not self.__eq__(vector)

    def __neg__(self):
        return Vector2(-self.x, -self.y)

    def __str__(self):
        return str([self.x, self.y])

    def __sub__(self, vector):
        return Vector2(self.x-vector.x, self.y-vector.y)

    def __truediv__(self, scalar):
        return self.__div__(scalar)

    def length(self):
        return math.sqrt(self.x**2+self.y**2)

    def normalize(self):
        length = self.length()
        return Vector2(self.x/length, self.y/length)

    def scale_to_length(self, scalar):
        length = self.length()
        self.x *= scalar/length
        self.y *= scalar/length

